from .error import InternalError as InternalError
from _typeshed import Incomplete
from collections import MutableMapping
from collections.abc import Generator

MATCH_VERSION: Incomplete

class Config(MutableMapping):
    def __init__(self, odoo, options) -> None: ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value) -> None: ...
    def __delitem__(self, key) -> None: ...
    def __iter__(self): ...
    def __len__(self) -> int: ...

def clean_version(version): ...
def v(version): ...
def get_encodings(hint_encoding: str = "utf-8") -> Generator[Incomplete, None, None]: ...
