from odoorpc import error as error
from odoorpc.tools import v as v

def encode2bytes(data): ...

class DB:
    def __init__(self, odoo) -> None: ...
    def dump(self, password, db, format_: str = "zip"): ...
    def change_password(self, password, new_password) -> None: ...
    def create(self, password, db, demo: bool = False, lang: str = "en_US", admin_password: str = "admin") -> None: ...
    def drop(self, password, db): ...
    def duplicate(self, password, db, new_db) -> None: ...
    def list(self): ...
    def restore(self, password, db, dump, copy: bool = False) -> None: ...
