def get_all(rc_file: str = "~/.odoorpcrc"): ...
def get(name, rc_file: str = "~/.odoorpcrc"): ...
def save(name, data, rc_file: str = "~/.odoorpcrc") -> None: ...
def remove(name, rc_file: str = "~/.odoorpcrc") -> None: ...
