from _typeshed import Incomplete
from odoorpc.tools import get_encodings as get_encodings, v as v

def encode2bytes(data): ...

class Report:
    def __init__(self, odoo) -> None: ...
    def download(self, name: str, ids: list[int], datas: Incomplete | None = None, context: Incomplete | None = None): ...
    def list(self) -> dict: ...
